==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/sr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Дати оператор није исправан",
    "The given regular expression is invalid" : "Дати регуларни израз није исправан",
    "The given file size is invalid" : "Дата величина фајла није исправна",
    "The given tag id is invalid" : "Дати ИД ознаке није исправан",
    "The given IP range is invalid" : "Дати опсег ИП адреса није исправан",
    "The given IP range is not valid for IPv4" : "Дати опсег ИП адреса није исправан за IPv4",
    "The given IP range is not valid for IPv6" : "Дати опсег ИП адреса није исправан за IPv6",
    "The given time span is invalid" : "Дати временски оквир није исправан",
    "The given start time is invalid" : "Дато време почетка није исправно",
    "The given end time is invalid" : "Дато време краја није исправно",
    "The given group does not exist" : "Дата група не постоји",
    "File" : "Фајл",
    "File created" : "Фајл направљен",
    "File updated" : "Фајл измењен",
    "File renamed" : "Фајл преименован",
    "File deleted" : "Фајл обрисан",
    "File accessed" : "Фајлу приступљено",
    "File copied" : "Фајл копиран",
    "Tag assigned" : "Додељена ознака",
    "Someone" : "Неко",
    "%s created %s" : "%s је направио %s",
    "%s modified %s" : "%s је изменио %s",
    "%s deleted %s" : "%s је обрисао %s",
    "%s accessed %s" : "%s је приступио %s",
    "%s renamed %s" : "%s је преименовао %s",
    "%s copied %s" : "%s је копирао %s",
    "%s assigned %s to %s" : "%s је доделио %s на %s",
    "Operation #%s does not exist" : "Операција #%s не постоји",
    "Entity %s does not exist" : "Ентитет %s не постоји",
    "Entity %s is invalid" : "Ентитет %s није исправан",
    "No events are chosen." : "Није одабран ниједан догађај.",
    "Entity %s has no event %s" : "Ентитет %s нема ниједан догађај %s",
    "Operation %s does not exist" : "Операција %s не постоји",
    "Operation %s is invalid" : "Операција %s није исправна",
    "At least one check needs to be provided" : "Треба да се зада бар једна провера",
    "Invalid check provided" : "Задата неисправна потврда",
    "Check %s does not exist" : "Проверите да ли %s постоји",
    "Check %s is invalid" : "Проверите да ли је %s исправно",
    "Check %s is not allowed with this entity" : "Провера %s није дозвољена са овим ентитетом",
    "Check #%s does not exist" : "Проверите да ли #%s постоји",
    "Check %s is invalid or does not exist" : "Проверите да ли је %s неисправно или не постоји",
    "Flow" : "Ток",
    "Nextcloud workflow engine" : "Некстклауд мотор тока рада",
    "Select a filter" : "Одаберите филтер",
    "Select a comparator" : "Одаберите компаратор",
    "Select a file type" : "Одаберите тип фајла",
    "e.g. httpd/unix-directory" : "нпр. httpd/unix-directory",
    "Images" : "Слике",
    "Office documents" : "Канцеларијски документи",
    "PDF documents" : "PDF документи",
    "Custom mimetype" : "Произвољни MIME тип",
    "Select a tag" : "Одаберите ознаку",
    "No results" : "Нема резултата",
    "%s (invisible)" : "%s (невидљив)",
    "%s (restricted)" : "%s (ограничен)",
    "Please enter a valid time span" : "Унесите исправан временски распон",
    "Select a request URL" : "Одабери адресу захтева",
    "Predefined URLs" : "Предефинисане адресе",
    "Files WebDAV" : "WebDAV фајлови",
    "Others" : "Остали",
    "Custom URL" : "Произвољна адреса",
    "Select a user agent" : "Одаберите агента захтева",
    "Android client" : "Андроид клијент",
    "iOS client" : "iOS клијент",
    "Desktop client" : "Десктоп клијент",
    "Thunderbird & Outlook addons" : "Додаци за Thunderbird & Outlook",
    "Custom user agent" : "Произвољни агент захтева",
    "At least one event must be selected" : "Мора бити одабран бар један догађај",
    "Add new flow" : "Додај нови ток",
    "When" : "Када",
    "and" : "и",
    "Cancel" : "Откажи",
    "Delete" : "Обриши",
    "The configuration is invalid" : "Конфигурација је неисправна",
    "Active" : "Активан",
    "Save" : "Сачувај",
    "Available flows" : "Доступни токови",
    "For details on how to write your own flow, check out the development documentation." : "За детаље како писати Ваш ток, погледај програмерску документацију.",
    "More flows" : "Још токова",
    "Browse the app store" : "Прегледајте продавницу апликација",
    "Show less" : "Прикажи мање",
    "Show more" : "Прикажи више",
    "Configured flows" : "Подешени токови",
    "Your flows" : "Ваши токови",
    "matches" : "се поклапа са",
    "does not match" : "се не поклапа са",
    "is" : "је",
    "is not" : "није",
    "File name" : "Име фајла",
    "File MIME type" : "MIME тип фајла",
    "File size (upload)" : "Величина фајла (отпремање)",
    "less" : "је мања од",
    "less or equals" : "мања или једнака од",
    "greater or equals" : "већа или једнака од",
    "greater" : "већа од",
    "Request remote address" : "Захтевај удаљену адресу",
    "matches IPv4" : "поклапа се са  IPv4 адресом",
    "does not match IPv4" : "не поклапа се са IPv4 адресом",
    "matches IPv6" : "поклапа се са IPv6 адресом",
    "does not match IPv6" : "не поклапа се са IPv6 адресом",
    "File system tag" : "Системска ознака фајла",
    "is tagged with" : "је означен са",
    "is not tagged with" : "није означен са",
    "Request URL" : "Адреса захтева",
    "Request time" : "Време захтева",
    "between" : "између",
    "not between" : "није између",
    "Request user agent" : "Кориснички агент захтева",
    "User group membership" : "Припадност групи",
    "is member of" : "је члан групе",
    "is not member of" : "није члан групе",
    "Short rule description" : "Кратки опис правила",
    "Add rule" : "Додај правило",
    "Reset" : "Ресетуј",
    "Saving…" : "Чувам…",
    "Group list is empty" : "Списак група је празан",
    "Unable to retrieve the group list" : "Није могуће дохватити списак група",
    "Saved" : "Снимљено",
    "Saving failed:" : "Снимање није успело:",
    "Add rule group" : "Додај групу правила",
    "Example: {placeholder}" : "Пример: {placeholder}",
    "Select tag…" : "Одаберите ознаку…",
    "Start" : "Почетак",
    "End" : "Крај",
    "Select timezone…" : "Одаберите временску зону…",
    "Sync clients" : "Синхронизовани клијенти",
    "Tag management" : "Управљање ознакама",
    "Files workflow engine" : "Датотеке за мотор процеса рада",
    "Open documentation" : "Отвори документацију",
    "Loading…" : "Учитавање…"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-19.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/sr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Дати оператор није исправан",
    "The given regular expression is invalid" : "Дати регуларни израз није исправан",
    "The given file size is invalid" : "Дата величина фајла није исправна",
    "The given tag id is invalid" : "Дати ИД ознаке није исправан",
    "The given IP range is invalid" : "Дати опсег ИП адреса није исправан",
    "The given IP range is not valid for IPv4" : "Дати опсег ИП адреса није исправан за IPv4",
    "The given IP range is not valid for IPv6" : "Дати опсег ИП адреса није исправан за IPv6",
    "The given time span is invalid" : "Дати временски оквир није исправан",
    "The given start time is invalid" : "Дато време почетка није исправно",
    "The given end time is invalid" : "Дато време краја није исправно",
    "The given group does not exist" : "Дата група не постоји",
    "File" : "Фајл",
    "File created" : "Фајл направљен",
    "File updated" : "Фајл измењен",
    "File renamed" : "Фајл преименован",
    "File deleted" : "Фајл обрисан",
    "File accessed" : "Фајлу приступљено",
    "File copied" : "Фајл копиран",
    "Tag assigned" : "Додељена ознака",
    "Someone" : "Неко",
    "%s created %s" : "%s је направио %s",
    "%s modified %s" : "%s је изменио %s",
    "%s deleted %s" : "%s је обрисао %s",
    "%s accessed %s" : "%s је приступио %s",
    "%s renamed %s" : "%s је преименовао %s",
    "%s copied %s" : "%s је копирао %s",
    "%s assigned %s to %s" : "%s је доделио %s на %s",
    "Operation #%s does not exist" : "Операција #%s не постоји",
    "Entity %s does not exist" : "Ентитет %s не постоји",
    "Entity %s is invalid" : "Ентитет %s није исправан",
    "No events are chosen." : "Није одабран ниједан догађај.",
    "Entity %s has no event %s" : "Ентитет %s нема ниједан догађај %s",
    "Operation %s does not exist" : "Операција %s не постоји",
    "Operation %s is invalid" : "Операција %s није исправна",
    "At least one check needs to be provided" : "Треба да се зада бар једна провера",
    "Invalid check provided" : "Задата неисправна потврда",
    "Check %s does not exist" : "Проверите да ли %s постоји",
    "Check %s is invalid" : "Проверите да ли је %s исправно",
    "Check %s is not allowed with this entity" : "Провера %s није дозвољена са овим ентитетом",
    "Check #%s does not exist" : "Проверите да ли #%s постоји",
    "Check %s is invalid or does not exist" : "Проверите да ли је %s неисправно или не постоји",
    "Flow" : "Ток",
    "Nextcloud workflow engine" : "Некстклаудов мотор радног тока",
    "Select a filter" : "Одаберите филтер",
    "Select a comparator" : "Одаберите компаратор",
    "Select a file type" : "Одаберите тип фајла",
    "e.g. httpd/unix-directory" : "нпр. httpd/unix-directory",
    "Folder" : "Фасцикла",
    "Images" : "Слике",
    "Office documents" : "Канцеларијски документи",
    "PDF documents" : "PDF документи",
    "Custom mimetype" : "Произвољни MIME тип",
    "Select a tag" : "Одаберите ознаку",
    "No results" : "Нема резултата",
    "%s (invisible)" : "%s (невидљив)",
    "%s (restricted)" : "%s (ограничен)",
    "Please enter a valid time span" : "Унесите исправан временски распон",
    "Select a request URL" : "Одабери адресу захтева",
    "Predefined URLs" : "Предефинисане адресе",
    "Files WebDAV" : "WebDAV фајлови",
    "Others" : "Остали",
    "Custom URL" : "Произвољна адреса",
    "Select a user agent" : "Одаберите агента захтева",
    "Android client" : "Андроид клијент",
    "iOS client" : "iOS клијент",
    "Desktop client" : "Десктоп клијент",
    "Thunderbird & Outlook addons" : "Додаци за Thunderbird & Outlook",
    "Custom user agent" : "Произвољни агент захтева",
    "At least one event must be selected" : "Мора бити одабран бар један догађај",
    "Add new flow" : "Додај нови ток",
    "When" : "Када",
    "and" : "и",
    "Cancel" : "Откажи",
    "Delete" : "Обриши",
    "The configuration is invalid" : "Конфигурација је неисправна",
    "Active" : "Активан",
    "Save" : "Сачувај",
    "Available flows" : "Доступни токови",
    "For details on how to write your own flow, check out the development documentation." : "За детаље како написати сопствени ток, погледајте програмерску документацију.",
    "More flows" : "Још токова",
    "Browse the app store" : "Прегледајте продавницу апликација",
    "Show less" : "Прикажи мање",
    "Show more" : "Прикажи више",
    "Configured flows" : "Подешени токови",
    "Your flows" : "Ваши токови",
    "matches" : "се поклапа са",
    "does not match" : "се не поклапа са",
    "is" : "је",
    "is not" : "није",
    "File name" : "Име фајла",
    "File MIME type" : "MIME тип фајла",
    "File size (upload)" : "Величина фајла (отпремање)",
    "less" : "је мања од",
    "less or equals" : "мања или једнака од",
    "greater or equals" : "већа или једнака од",
    "greater" : "већа од",
    "Request remote address" : "Захтевај удаљену адресу",
    "matches IPv4" : "поклапа се са  IPv4 адресом",
    "does not match IPv4" : "не поклапа се са IPv4 адресом",
    "matches IPv6" : "поклапа се са IPv6 адресом",
    "does not match IPv6" : "не поклапа се са IPv6 адресом",
    "File system tag" : "Системска ознака фајла",
    "is tagged with" : "је означен са",
    "is not tagged with" : "није означен са",
    "Request URL" : "Адреса захтева",
    "Request time" : "Време захтева",
    "between" : "између",
    "not between" : "није између",
    "Request user agent" : "Кориснички агент захтева",
    "User group membership" : "Припадност групи",
    "is member of" : "је члан групе",
    "is not member of" : "није члан групе",
    "Short rule description" : "Кратки опис правила",
    "Add rule" : "Додај правило",
    "Reset" : "Ресетуј",
    "Saving…" : "Чувам…",
    "Group list is empty" : "Списак група је празан",
    "Unable to retrieve the group list" : "Не могу да добавим списак група",
    "Saved" : "Снимљено",
    "Saving failed:" : "Снимање није успело:",
    "Add rule group" : "Додај групу правила",
    "Example: {placeholder}" : "Пример: {placeholder}",
    "Select tag…" : "Одаберите ознаку…",
    "Start" : "Почетак",
    "End" : "Крај",
    "Select timezone…" : "Одаберите временску зону…",
    "Sync clients" : "Синхронизовани клијенти",
    "Tag management" : "Управљање ознакама",
    "Files workflow engine" : "Мотор за радни ток фајлова",
    "Open documentation" : "Отвори документацију",
    "Loading…" : "Учитавање…"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
